/**
 * EasyBeans
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: WarArchiveHelper.java 2752 2008-04-02 09:20:29Z gaellalire $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.deployment.annotations.analyzer;

import java.net.URL;
import java.util.ArrayList;
import java.util.List;

import org.ow2.util.deployment.annotations.analyzer.ArchiveHelper;
import org.ow2.util.ee.deploy.api.archive.IArchive;

/**
 * This class is a temporary solution to solve war archive scan issue. Indeed an
 * instance of a class which implements ArchiveHelper should not be archive
 * dependent.
 * @author Gael Lalire
 */
public class WarArchiveHelper implements ArchiveHelper {

    /**
     * The list of class inside war archive.
     */
    private List<URL> classURLList;

    /**
     * A class loader which can be used to load classes.
     */
    private ClassLoader classLoader;

    /**
     * WarArchiveHelper constructor.
     * @param classNameList the list of class inside war archive
     * @param classLoader a classloader which can be used to load classes
     */
    public WarArchiveHelper(final List<String> classNameList, final ClassLoader classLoader) {
        this.classURLList = new ArrayList<URL>();
        for (String className : classNameList) {
            this.classURLList.add(classLoader.getResource(className.replace('.', '/').concat(".class")));
        }
        this.classLoader = classLoader;
    }

    /**
     * @param archive the archive
     * @param className a class name
     * @return url of className inside the archive
     */
    public URL getClassURL(final IArchive archive, final String className) {
        return this.classLoader.getResource(className.replace('.', '/').concat(".class"));
    }

    /**
     * @param archive the archive
     * @return the list of all classes in archive
     */
    public List<URL> listClassURL(final IArchive archive) {
        return this.classURLList;
    }

}
